@@ -155,15 +155,15 @@ class Check(util.Dimensions):
         """Simple rate.
         """
         try:
-            interval = sample2[0] - sample1[0]
-            if interval == 0:
+            rate_interval = sample2[0] - sample1[0]
+            if rate_interval == 0:
                 raise exceptions.Infinity()
 
             delta = sample2[1] - sample1[1]
             if delta < 0:
                 raise exceptions.UnknownValue()
 
-            return (sample2[0], delta / interval, sample2[2], sample2[3])
+            return (sample2[0], delta / rate_interval, sample2[2], sample2[3])
         except exceptions.Infinity:
             raise
         except exceptions.UnknownValue:
@@ -308,7 +308,7 @@ class AgentCheck(util.Dimensions):
         """
         self.aggregator.gauge(metric,
                               value,
-                              self._set_dimensions(dimensions),
+                              dimensions,
                               delegated_tenant,
                               hostname,
                               device_name,
@@ -326,7 +326,7 @@ class AgentCheck(util.Dimensions):
         """
         self.aggregator.increment(metric,
                                   value,
-                                  self._set_dimensions(dimensions),
+                                  dimensions,
                                   delegated_tenant,
                                   hostname,
                                   device_name)
@@ -343,7 +343,7 @@ class AgentCheck(util.Dimensions):
         """
         self.aggregator.decrement(metric,
                                   value,
-                                  self._set_dimensions(dimensions),
+                                  dimensions,
                                   delegated_tenant,
                                   hostname,
                                   device_name)
@@ -363,7 +363,7 @@ class AgentCheck(util.Dimensions):
         """
         self.aggregator.rate(metric,
                              value,
-                             self._set_dimensions(dimensions),
+                             dimensions,
                              delegated_tenant,
                              hostname,
                              device_name)
@@ -380,7 +380,7 @@ class AgentCheck(util.Dimensions):
         """
         self.aggregator.histogram(metric,
                                   value,
-                                  self._set_dimensions(dimensions),
+                                  dimensions,
                                   delegated_tenant,
                                   hostname,
                                   device_name)
@@ -397,7 +397,7 @@ class AgentCheck(util.Dimensions):
         """
         self.aggregator.set(metric,
                             value,
-                            self._set_dimensions(dimensions),
+                            dimensions,
                             delegated_tenant,
                             hostname,
                             device_name)
