@@ -13,34 +13,38 @@ import sys
 import yaml
 
 import agent_config
-import detection.plugins.apache as apache
-import detection.plugins.ceilometer as ceilometer
-import detection.plugins.cinder as cinder
-import detection.plugins.glance as glance
-import detection.plugins.kafka_consumer as kafka_consumer
-import detection.plugins.keystone as keystone
-import detection.plugins.libvirt as libvirt
-import detection.plugins.mon as mon
-import detection.plugins.mysql as mysql
-import detection.plugins.network as network
-import detection.plugins.neutron as neutron
-import detection.plugins.nova as nova
-import detection.plugins.rabbitmq as rabbitmq
-import detection.plugins.swift as swift
-import detection.plugins.zookeeper as zookeeper
+from detection.plugins import DETECTION_PLUGINS
 import service.sysv as sysv
 
+from detection.utils import check_output
+
 # List of all detection plugins to run
-DETECTION_PLUGINS = [apache.Apache, ceilometer.Ceilometer, cinder.Cinder,
-                     glance.Glance, kafka_consumer.Kafka, keystone.Keystone,
-                     libvirt.Libvirt, mon.MonAPI, mon.MonPersister, mon.MonThresh,
-                     mysql.MySQL, network.Network, neutron.Neutron, nova.Nova,
-                     rabbitmq.RabbitMQ, swift.Swift, zookeeper.Zookeeper]
 # Map OS to service type
 OS_SERVICE_MAP = {'Linux': sysv.SysV}
 
 log = logging.getLogger(__name__)
 
+# dirname is called twice to get the dir 1 above the location of the script
+PREFIX_DIR = os.path.dirname(os.path.dirname(os.path.realpath(sys.argv[0])))
+
+
+def write_template(template_path, out_path, variables, group):
+    """ Write a file using a simple python string template.
+        Assumes 640 for the permissions and root:group for ownership.
+    :param template_path: Location of the Template to use
+    :param out_path: Location of the file to write
+    :param variables: dictionary with key/value pairs to use in writing the template
+    :return: None
+    """
+    if not os.path.exists(template_path):
+        print("Error no template found at {0}".format(template_path))
+        sys.exit(1)
+    with open(template_path, 'r') as template:
+        with open(out_path, 'w') as conf:
+            conf.write(template.read().format(**variables))
+    os.chown(out_path, 0, group)
+    os.chmod(out_path, 0640)
+
 
 def main(argv=None):
     parser = argparse.ArgumentParser(description='Detect running daemons then configure and start the agent.',
@@ -50,7 +54,7 @@ def main(argv=None):
     parser.add_argument(
         '-p', '--password', help="Password used for keystone authentication", required=True)
     parser.add_argument('--keystone_url', help="Keystone url", required=True)
-    parser.add_argument('--monasca_url', help="Monasca API url", required=True)
+    parser.add_argument('--monasca_url', help="Monasca API url, if not defined the url is pulled from keystone", required=False, default='')
     parser.add_argument('--insecure', help="Set whether certificates are used for Keystone authentication", required=False, default=False)
     parser.add_argument('--project_name', help="Project name for keystone authentication", required=False, default='')
     parser.add_argument('--project_domain_id', help="Project domain id for keystone authentication", required=False, default='')
@@ -58,12 +62,14 @@ def main(argv=None):
     parser.add_argument('--project_id', help="Keystone project id  for keystone authentication", required=False, default='')
     parser.add_argument('--ca_file', help="Sets the path to the ca certs file if using certificates. " +
                                           "Required only if insecure is set to False", required=False, default='')
+    parser.add_argument('--check_frequency', help="How often to run metric collection in seconds", type=int, default=15)
     parser.add_argument('--config_dir', help="Configuration directory", default='/etc/monasca/agent')
     parser.add_argument('--dimensions', help="Additional dimensions to set for all metrics. A comma seperated list " +
                                              "of name/value pairs, 'name:value,name2:value2'")
     parser.add_argument('--log_dir', help="monasca-agent log directory", default='/var/log/monasca/agent')
+    parser.add_argument('--log_level', help="monasca-agent logging level (ERROR, WARNING, INFO, DEBUG)", required=False, default='INFO')
     parser.add_argument(
-        '--template_dir', help="Alternative template directory", default='/usr/local/share/monasca/agent')
+        '--template_dir', help="Alternative template directory", default=os.path.join(PREFIX_DIR, 'share/monasca/agent'))
     parser.add_argument('--headless', help="Run in a non-interactive mode", action="store_true")
     parser.add_argument('--overwrite',
                         help="Overwrite existing plugin configuration. " +
@@ -91,14 +97,14 @@ def main(argv=None):
         linux_flavor = platform.linux_distribution()[0]
         if 'Ubuntu' or 'debian' in linux_flavor:
             for package in ['coreutils', 'sysstat']:
-                #Check for required dependencies for system checks
+                # Check for required dependencies for system checks
                 try:
-                    output = subprocess.check_output('dpkg -s {}'.format(package),
-                                                     stderr=subprocess.STDOUT,
-                                                     shell=True)
+                    output = check_output('dpkg -s {0}'.format(package),
+                                          stderr=subprocess.STDOUT,
+                                          shell=True)
                 except subprocess.CalledProcessError:
-                    log.warn("*** {} package is not installed! ***".format(package) +
-                             "\nNOTE: If you do not install the {} ".format(package) +
+                    log.warn("*** {0} package is not installed! ***".format(package) +
+                             "\nNOTE: If you do not install the {0} ".format(package) +
                              "package, you will not receive all of the standard " +
                              "operating system type metrics!")
         else:
@@ -114,32 +120,33 @@ def main(argv=None):
 
     # Service enable, includes setup of users/config directories so must be
     # done before configuration
-    agent_service = OS_SERVICE_MAP[detected_os](os.path.join(args.template_dir, 'monasca-agent.init'),
+    agent_service = OS_SERVICE_MAP[detected_os](PREFIX_DIR,
                                                 args.config_dir,
-                                                args.log_dir, username=args.user)
+                                                args.log_dir,
+                                                args.template_dir,
+                                                username=args.user)
     if not args.skip_enable:
         agent_service.enable()
 
     gid = pwd.getpwnam(args.user).pw_gid
     # Write the main agent.conf - Note this is always overwritten
     log.info('Configuring base Agent settings.')
-    agent_conf_path = os.path.join(args.config_dir, 'agent.conf')
-    with open(os.path.join(args.template_dir, 'agent.conf.template'), 'r') as agent_template:
-        with open(agent_conf_path, 'w') as agent_conf:
-            # Join service in with the dimensions
-            if args.service:
-                if args.dimensions is None:
-                    args.dimensions = 'service:' + args.service
-                else:
-                    args.dimensions = ','.join([args.dimensions, 'service:' + args.service])
-            agent_conf.write(agent_template.read().format(args=args, hostname=socket.getfqdn()))
-    os.chown(agent_conf_path, 0, gid)
-    os.chmod(agent_conf_path, 0o640)
-    # Link the supervisor.conf
-    supervisor_path = os.path.join(args.config_dir, 'supervisor.conf')
-    if os.path.exists(supervisor_path):
-        os.remove(supervisor_path)
-    os.symlink(os.path.join(args.template_dir, 'supervisor.conf'), supervisor_path)
+    # Join service in with the dimensions
+    if args.service:
+        if args.dimensions is None:
+            args.dimensions = 'service:' + args.service
+        else:
+            args.dimensions = ','.join([args.dimensions, 'service:' + args.service])
+    write_template(os.path.join(args.template_dir, 'agent.conf.template'),
+                   os.path.join(args.config_dir, 'agent.conf'),
+                   {'args': args, 'hostname': socket.getfqdn() },
+                   gid)
+
+    # Write the supervisor.conf
+    write_template(os.path.join(args.template_dir, 'supervisor.conf.template'),
+                   os.path.join(args.config_dir, 'supervisor.conf'),
+                   {'prefix': PREFIX_DIR, 'log_dir': args.log_dir},
+                   gid)
 
     # Run through detection and config building for the plugins
     plugin_config = agent_config.Plugins()
